@@ -2,12 +2,10 @@ from .aws import S3Location, LoadPartitions
 from .db import CachedAthenaQuery, CachedPep249Query, BaseCachedQuery, AthenaClient, SqlClient
 from .doggo import PandasDoggo, FileDoggo, CSVDoggo, DoggoFileSystem, DoggoLock, DoggoWait, DynamoDogLock
 from .log import log_to_stdout, PersistentFieldLogger
-from .tests import BaseTest
 
 __all__ = ['S3Location',
            'CachedAthenaQuery', 'CachedPep249Query', 'BaseCachedQuery',
            'PandasDoggo', 'FileDoggo', 'CSVDoggo', 'DoggoFileSystem',
            'DoggoLock', 'DoggoWait', 'log_to_stdout', 'PersistentFieldLogger',
-           'AthenaClient', 'SqlClient',
-           'BaseTest', 'LoadPartitions'
-           ]
\ No newline at end of file
+           'AthenaClient', 'SqlClient', 'LoadPartitions'
+           ]
