@@ -20,6 +20,12 @@ This is made up as follows:
 * **ba98cb6452cf711ae0cec5c2dadc2585** - This is a unique hash calculated from the parameters passed to the SQL file. A new file is created for each set of parameters passed to the file
 * **.csv.gz** - A fixed prefix, always set to “.csv.gz”
 
+Caches can optionally be set to expiree very n seconds in which case the cache will appear as follows:
+``s3://cache_bucket/cache_prefix/get_results_5e5920011161b3081937572d25140237_ba98cb6452cf711ae0cec5c2dadc2585_1616518700.csv.gz``
+
+In thiase case 1616518700 refers to the epoch time, at which the n seconds starts for which this cache is valid. For example, if you set for the cache to be valid for 60 seconds then a
+new cache will be created each minute
+
 Hash collisions
 ---------------
 
@@ -43,6 +49,7 @@ or by creating a row in DynamoDB to lock the file. The table in DynamoDB is "new
 
 """
 
+import time
 import json
 import datetime
 import logging
@@ -63,11 +70,13 @@ S3fsMixin = DoggoFileSystem
 
 class BaseCachedClass:
     validation_mode = False
+    _expiry_seconds = 0
 
-    def __init__(self, cache_path, logger=logging.getLogger("newtools.cached_query")):
+    def __init__(self, cache_path, logger=logging.getLogger("newtools.cached_query"), expiry_seconds=0):
         self.cache_path = cache_path
         self.dfs = DoggoFileSystem()
         self._logger = logger
+        self._expiry_seconds = expiry_seconds
 
     def _exists(self, path):
         """
@@ -124,6 +133,16 @@ class BaseCachedClass:
 
         hash_list = [prefix, self._get_file_hash(files_to_hash)] + data_hash
 
+        if self._expiry_seconds > 0:
+            # Truncate the epoch to the expiry seconds and add to the hash list
+            # For example, if the epoch is 1616681824 and we are expiring every 100 seconds
+            # the expiry time in the hash will be to set to 1616681800.
+            #
+            # This means than any query run before 1616681900 will use the same expiry hash
+            # and pick up the cached version.
+            epoch = int(int(time.time()))
+            hash_list.append(str(epoch - epoch % self._expiry_seconds))
+
         file = "_".join(hash_list) + ".csv" + suffix
 
         if self.cache_path.startswith("s3://"):
@@ -143,7 +162,7 @@ class BaseCachedQuery(BaseCachedClass):
     maximum_age = 3600
 
     def __init__(self, params=None, cache_path="", sql_archive_path=None, sql_paths=None, gzip=True,
-                 dynamodb_lock=True, logger=logging.getLogger("newtools.cached_query")):
+                 dynamodb_lock=True, logger=logging.getLogger("newtools.cached_query"), expiry_seconds=0):
         """
         Cached query class
 
@@ -154,8 +173,9 @@ class BaseCachedQuery(BaseCachedClass):
         :param gzip: if set, then results will be compression
         :param dynamodb_lock: defaults to True, using Dynamo DB for locking in S3
         :param logger: the logger to use for this class and any newtools classes created by this class
+        :param expiry_seconds: if set, caches files we expire every expiry_seconds seconds.
         """
-        super().__init__(cache_path, logger)
+        super().__init__(cache_path, logger, expiry_seconds)
 
         self._logger = logger
         self._gzip = gzip
@@ -314,7 +334,8 @@ class BaseCachedQuery(BaseCachedClass):
                     sql_file,
                     output_prefix,
                     params=None,
-                    replacement_dict=None):
+                    replacement_dict=None,
+                    refresh_cache=False):
         """
         Runs the specified SQL file
 
@@ -322,6 +343,7 @@ class BaseCachedQuery(BaseCachedClass):
         :param output_prefix: the output path to use for this query
         :param params: the parameters to use in the query
         :param replacement_dict: and replacement to be made in the query's text
+        :param refresh_cache: if set, then the cache for this query is refreshed when it is run
         :return:
         """
 
@@ -347,32 +369,39 @@ class BaseCachedQuery(BaseCachedClass):
 
         self._log_parameters(params)
 
-        if not self._exists(output_file):
-            with self._get_lock(output_file):
-                if not self._exists(output_file):
-                    # clean up any S3 files with the same prefix
-                    for file in self.dfs.glob(output_file + "**"):
-                        self.dfs.rm(file)
+        if self._exists(output_file):
+            if refresh_cache:
+                self._logger.info("Refreshing cache at {0}".format(output_file))
+                with self._get_lock(output_file):
+                    self.dfs.rm(output_file)
+            else:
+                self._logger.info("Loading query from {0}".format(output_file))
+                return output_file
 
-                    self._logger.info("Executing query to {0}".format(output_file))
-                    self._execute_query(query_file=file_path,
-                                        output_file=output_file,
-                                        query_parameters=query_parameters,
-                                        replacement_dict={} if replacement_dict is None else replacement_dict)
+        # Get the lock and create the output file
+        with self._get_lock(output_file):
+            if not self._exists(output_file):
+                # clean up any S3 files with the same prefix
+                for file in self.dfs.glob(output_file + "**"):
+                    self.dfs.rm(file)
 
-                    # In the S3 case, redshift files are saved with a prefix and need to be renamed
-                    if self._redshift_checks and output_file.startswith("s3://"):
-                        if not self.dfs.exists(output_file):
-                            files = self.dfs.glob(output_file + "**")
-                            if len(files) == 0:
-                                raise ValueError("No file returned by the query. Does it contain an UNLOAD command?")
-                            elif len(files) > 1:
-                                raise ValueError(
-                                    "More than one file produced by query. Is PARALLEL OFF set in your UNLOAD command?")
-                            else:
-                                self.dfs.mv(files[0], output_file)
+                self._logger.info("Executing query to {0}".format(output_file))
+                self._execute_query(query_file=file_path,
+                                    output_file=output_file,
+                                    query_parameters=query_parameters,
+                                    replacement_dict={} if replacement_dict is None else replacement_dict)
 
-        self._logger.info("Loading query from {0}".format(output_file))
+                # In the S3 case, redshift files are saved with a prefix and need to be renamed
+                if self._redshift_checks and output_file.startswith("s3://"):
+                    if not self.dfs.exists(output_file):
+                        files = self.dfs.glob(output_file + "**")
+                        if len(files) == 0:
+                            raise ValueError("No file returned by the query. Does it contain an UNLOAD command?")
+                        elif len(files) > 1:
+                            raise ValueError(
+                                "More than one file produced by query. Is PARALLEL OFF set in your UNLOAD command?")
+                        else:
+                            self.dfs.mv(files[0], output_file)
         return output_file
 
     def _execute_query(self, **params):
@@ -413,8 +442,8 @@ class CachedPep249Query(BaseCachedQuery):
     _redshift_checks = True
 
     def __init__(self, pep_249_obj, params=None, cache_path="", sql_archive_path=None, sql_paths=None, gzip=True,
-                 dynamodb_lock=True, logger=logging.getLogger("newtools.cached_query")):
-        super().__init__(params, cache_path, sql_archive_path, sql_paths, gzip, dynamodb_lock, logger)
+                 dynamodb_lock=True, logger=logging.getLogger("newtools.cached_query"), expiry_seconds=0):
+        super().__init__(params, cache_path, sql_archive_path, sql_paths, gzip, dynamodb_lock, logger, expiry_seconds)
 
         self._sql = SqlClient(pep_249_obj,
                               logger=logger,
@@ -506,8 +535,8 @@ class CachedAthenaQuery(BaseCachedQuery):
 
     def __init__(self, params=None, cache_path="", sql_archive_path=None, sql_paths=None, gzip=True,
                  dynamodb_lock=True, logger=logging.getLogger("newtools.cached_query"),
-                 queue_queries=False):
-        super().__init__(params, cache_path, sql_archive_path, sql_paths, gzip, dynamodb_lock, logger)
+                 queue_queries=False, expiry_seconds=0):
+        super().__init__(params, cache_path, sql_archive_path, sql_paths, gzip, dynamodb_lock, logger, expiry_seconds)
 
         self._results = dict()
         self.queue_queries = queue_queries
