@@ -260,7 +260,7 @@ class PandasDoggo:
 
             # Save the dataframe
             self.save(group_df[[col for col in df.columns if col not in partition_columns]],
-                      file, compression, *args, **kwargs)
+                      file, compression=compression, *args, **kwargs)
 
             # Add to the list to return
             paths.append(file)
