@@ -35,10 +35,13 @@ Cross-platform supports for reading, writing, copying, deleting, etc... files fr
 import shutil
 import os
 from glob import glob
-from newtools.optional_imports import s3fs
+from newtools.optional_imports import s3fs, boto3
 from newtools.aws import S3Location
 from .doggo import FileDoggo
+from newtools.log import log_to_stdout
 
+import fnmatch
+logger = log_to_stdout('Deductive - DoggoFileSystem')
 
 class DoggoFileSystem:
     """
@@ -48,10 +51,13 @@ class DoggoFileSystem:
     """
     __s3fs = None
 
-    def __init__(self, session=None):
+    def __init__(self, session=None, boto3_session=None):
         s3fs.S3FileSystem.read_timeout = 600
         self.__s3fs = s3fs.S3FileSystem(session=session)
 
+        self.s3_session = boto3_session if boto3_session else boto3.session.Session()
+        self.s3_client = self.s3_session.client('s3')
+
     @property
     def _s3fs(self):
         """
@@ -208,9 +214,20 @@ class DoggoFileSystem:
         if self.is_s3(location) and not recursive:
             return [S3Location(item) for item in self._s3fs.glob(location)] if location.endswith('/') else [
                 S3Location(item) for item in self._s3fs.glob(location + '/')]
+
         elif self.is_s3(location) and recursive:
-            result = self._fetch(location, None)
-            return result if result != [S3Location(location)] else []
+            bucket = S3Location(location).bucket
+            prefix = S3Location(location).key
+            try:
+                if prefix is None:
+                    files = self._list_files(bucket=bucket)
+                else:
+                    files = self._list_files(bucket=bucket, prefix=prefix)
+                return [S3Location(bucket).join(file) for file in files]
+            except self.s3_client.exceptions.ClientError as e:
+                logger.error(e)
+                return[]
+
         elif recursive:
             file_list = []
             for item in os.walk(location):
@@ -220,36 +237,9 @@ class DoggoFileSystem:
         else:
             try:
                 return [os.path.join(location, item) for item in os.listdir(location)]
-            except (FileNotFoundError, NotADirectoryError):
-                return []
-
-    def _fetch(self, input_list, output_list=None):
-        """
-        lists the contents of a directory. If recursive =True, then will assume all things in the directory are
-        folders and try to list their contents. Anything which returns nothing will be treated like a file and added
-        to the return. If recursive=False, then it will also list folders. Always lists full path to file/folder.
-
-        :param input_list: dubiously named because it can be a string, but will be converted to a list. directory
-        to look for files in, if its in s3 ideally ends with a /
-        :param output_list: should be None if calling function, used for recursion
-        """
-        output_list = output_list if output_list else []
-
-        input_list = [input_list] if type(input_list) != list else input_list
-
-        if not input_list:
-            return [S3Location(file) for file in output_list]
-
-        new_list = []
-
-        for s3_loc in input_list:
-            contents = self._s3fs.glob(s3_loc) if s3_loc.endswith('/') else self._s3fs.glob(s3_loc + '/')
-            if not contents:
-                output_list.append(s3_loc)
-            else:
-                new_list.extend(contents)
-
-        return self._fetch(new_list, output_list)
+            except (FileNotFoundError, NotADirectoryError) as e:
+                logger.error(e)
+                return[]
 
     def glob(self, glob_string):
         """
@@ -304,3 +294,106 @@ class DoggoFileSystem:
                 return S3Location(loc.bucket), loc.file
         else:
             return os.path.split(path)
+
+    def _files_within(self, directory_path, pattern):
+        """
+        Returns generator containing all the files in a directory
+        """
+        for dirpath, dirnames, filenames in os.walk(directory_path):
+            for file_name in fnmatch.filter(filenames, pattern):
+                yield os.path.join(dirpath, file_name)
+
+    def _put_folder(self, source, bucket, destination="", file_format="*"):
+        """
+       Copies files from a directory on local system to s3
+      +        :param source: Folder on local filesystem that must be copied to s3
+      +        :param bucket: s3 bucket in which files have to be copied
+      +        :param destination: Location on s3 bucket to which files have to be copied
+      +        :param file_format: pattern for files to be transferred
+      +        :return: None
+              """
+        if os.path.isdir(source):
+            file_list = list(self._files_within(source, file_format))
+            for each_file in file_list:
+                part_key = os.path.relpath(each_file, source)
+                key = os.path.join(destination, part_key)
+                self.s3_client.upload_file(each_file, bucket, key)
+        else:
+            raise ValueError("Source must be a valid directory path")
+
+    def _generate_keys(self, bucket, prefix, suffix="", start_after=None):
+
+        if start_after is None:
+            s3_objects = self.s3_client.list_objects_v2(Bucket=bucket,
+                                                        Prefix=prefix,
+                                                        MaxKeys=1000)
+        else:
+            s3_objects = self.s3_client.list_objects_v2(Bucket=bucket,
+                                                        Prefix=prefix,
+                                                        MaxKeys=1000,
+                                                        StartAfter=start_after)
+
+        if 'Contents' in s3_objects:
+            for key in s3_objects["Contents"]:
+                if key['Key'].endswith(suffix):
+                    yield key['Key']
+
+            # get the next keys
+            yield from self._generate_keys(bucket, prefix, suffix, s3_objects["Contents"][-1]['Key'])
+
+    def _delete(self, path, suffix=""):
+        loc = S3Location(path)
+        keys = []
+        for key in self._generate_keys(loc.bucket, loc.path, suffix):
+            keys.append({'Key': key})
+            if len(keys) == 1000:
+                self.s3_client.delete_objects(Bucket=loc.bucket,
+                                              Delete={"Objects": keys})
+                keys = []
+
+        if len(keys) > 0:
+            self.s3_client.delete_objects(Bucket=loc.bucket,
+                                          Delete={"Objects": keys})
+
+    def _delete_files(self, bucket, prefix, suffix=""):
+        return self._delete("s3://{0}/{1}".format(bucket, prefix), suffix)
+
+    def _list_files(self, bucket, prefix="", suffix=None, remove_prefix=False):
+        return self._list("s3://{0}/{1}".format(bucket, prefix), suffix, remove_prefix)
+
+    def _list(self, path, suffix=None, remove_prefix=False):
+        return [key['key'] for key in self._list_dict(path, suffix, remove_prefix)]
+
+    def _list_dict(self, path, suffix=None, remove_prefix=False):
+        """
+            Return details of files with particular prefix/suffix stored on S3
+
+            ## Parameters
+            - bucket: S3 bucket in which files are stored
+            - prefix: Prefix filter for files on S3
+            - suffix: Suffix filter for files on S3
+        """
+
+        loc = S3Location(path)
+
+        response = self.s3_client.list_objects_v2(Bucket=loc.bucket,
+                                                  Prefix=loc.path if loc.path else "")
+        while True:
+            if response and 'Contents' in response:
+                for key in response['Contents']:
+                    if not suffix or key['Key'].endswith(suffix):
+                        yield {
+                            'key': key['Key'].replace(loc.path, '') if loc.path and remove_prefix else key['Key'],
+                            'last_modified': key['LastModified'],
+                            'size': key['Size']
+                        }
+
+                # Do we need to carry on?
+                if response['IsTruncated'] and 'NextContinuationToken' in response:
+                    response = self.s3_client.list_objects_v2(Bucket=loc.bucket,
+                                                              Prefix=loc.path if loc.path else "",
+                                                              ContinuationToken=response['NextContinuationToken'])
+                else:
+                    break
+            else:
+                break
