@@ -1,8 +1,6 @@
 import unittest
 from os import path
-
-from dativa.tools.aws import S3Client
-
+from s3fs import S3FileSystem
 from newtools import AthenaClient, log_to_stdout
 
 logger = log_to_stdout("newtools")
@@ -10,11 +8,11 @@ logger = log_to_stdout("newtools")
 
 # noinspection SqlNoDataSourceInspection
 class AthenaTest(unittest.TestCase):
-    source_file = "s3://deductive-tools-testing/s3_upload_athena/demographic/"
+    source_file = "s3://newtools-testing/s3_upload_athena/demographic/"
     tablename = "demographic"
     region = "eu-west-1"
     database = "test_database"
-    bucket = "deductive-tools-testing"
+    bucket = "newtools-testing"
     output_location = "s3://aws-athena-query-results-933373196108-eu-west-1/"
     invalid_file_location = "/this/location/does/not/exist.csv"
     athena_client = None
@@ -25,13 +23,13 @@ class AthenaTest(unittest.TestCase):
         cls.base_path = "{0}/test_data/".format(
             path.dirname(path.abspath(__file__)))
         logger.info("Uploading test data to s3")
-        cls.s3 = S3Client()
-        cls.s3.delete_files(cls.bucket, "s3_upload_athena")
+        cls.s3 = S3FileSystem()
+        for file in cls.s3.glob(f"s3://{cls.bucket}/s3_upload_athena/*"):
+            cls.s3.rm(file)
 
-        cls.s3.put_folder(source=path.join(cls.base_path, "s3_upload_athena"),
-                          bucket=cls.bucket,
-                          destination="s3_upload_athena",
-                          file_format="*")
+        cls.s3.put(lpath=path.join(cls.base_path, "s3_upload_athena"),
+                   rpath=f"s3://{cls.bucket}/s3_upload_athena",
+                   recursive=True)
 
         cls.athena_client = AthenaClient(cls.region, cls.database, max_retries=2)
 
@@ -78,7 +76,9 @@ class AthenaTest(unittest.TestCase):
 
     def test_queries(self):
         logger.info("Querying athena")
-        self.s3.delete_files(self.bucket, "pq")
+        for file in self.s3.glob(f"s3://{self.bucket}/pq/*"):
+            self.s3.rm(file)
+
         self.athena_client.add_query("select * from {}".format(self.tablename),
                                      "athena_test",
                                      "{0}pq/".format(self.output_location))
@@ -94,7 +94,9 @@ class AthenaTest(unittest.TestCase):
         self.assertEqual(df_count.iloc[0, 0], 42)
 
     def test_stopping_queries(self):
-        self.s3.delete_files(self.bucket, "pq")
+        for file in self.s3.glob(f"s3://{self.bucket}/pq/*"):
+            self.s3.rm(file)
+
         ac = AthenaClient(self.region, self.database, max_retries=2, max_queries=1)
         ac.add_query("select * from {}".format(self.tablename),
                      "athena_test",
@@ -151,8 +153,7 @@ class AthenaTest(unittest.TestCase):
             pass
         finally:
             query = self.athena_client.add_query("select 0",
-                                         "athena_test",
-                                         self.output_location)
+                                                 "athena_test",
+                                                 self.output_location)
             self.athena_client.wait_for_completion()
             self.athena_client.get_query_result(query)
-
