@@ -3,7 +3,7 @@
 
 import sqlite3
 import os
-from time import time
+from time import time, sleep
 
 from datetime import datetime, timedelta
 
@@ -118,6 +118,39 @@ class TestCachedQuery(BaseTest):
 
         self.assertEqual(a, b)
 
+    def test_query_expiring_cache(self):
+        q = CachedPep249Query(self.sqlite_db,
+                              cache_path=self.tempdir,
+                              sql_paths=[self.sql_path],
+                              expiry_seconds=2,
+                              gzip=False)
+        self.set_timeouts(q)
+
+        # get to the point where a new two second period has started...
+        if int(int(time())) % 2 == 1:
+            sleep(1)
+
+        path1 = q.get_results(sql_file="test_select.sql",
+                              output_prefix="test_query",
+                              )
+
+        sleep(1)
+
+        path2 = q.get_results(sql_file="test_select.sql",
+                              output_prefix="test_query",
+                              )
+        sleep(2)
+
+        path3 = q.get_results(sql_file="test_select.sql",
+                              output_prefix="test_query",
+                              )
+
+        # Check the two queries run in the same period use the same path
+        self.assertEqual(path1, path2)
+
+        # Check the second query returns a different path
+        self.assertNotEqual(path1, path3)
+
     def test_query_pep249(self):
         q = CachedPep249Query(self.sqlite_db,
                               cache_path=self.tempdir,
@@ -221,14 +254,11 @@ class TestCachedQuery(BaseTest):
                 datetime.utcnow(),
                 datetime.utcnow() + timedelta(days=1)]
 
-        # Clear any previously cached file
-        q.clear_cache(sql_file="athena_test.sql",
-                      output_prefix="athena_test",
-                      params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
-
+        # Get the results, refreshing the cache
         r = q.get_results(sql_file="athena_test.sql",
                           output_prefix="athena_test",
-                          params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
+                          params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]},
+                          refresh_cache=True)
 
         # Get the output
         output = PandasDoggo().load_csv(r, compression="gzip")
@@ -342,15 +372,11 @@ class TestCachedQuery(BaseTest):
                 datetime.utcnow(),
                 datetime.utcnow() + timedelta(days=1)]
 
-        q.clear_cache(sql_file="athena_test.sql",
-                      output_prefix="athena_test",
-                      replacement_dict={
-                          "{day_list}": "(" + ",".join(["'{0:%Y-%m-%d}'".format(day) for day in days]) + ")"})
-
         r = q.get_results(sql_file="athena_test.sql",
                           output_prefix="athena_test",
                           replacement_dict={
-                              "{day_list}": "(" + ",".join(["'{0:%Y-%m-%d}'".format(day) for day in days]) + ")"})
+                              "{day_list}": "(" + ",".join(["'{0:%Y-%m-%d}'".format(day) for day in days]) + ")"},
+                          refresh_cache=True)
 
         # Get the output
         output = PandasDoggo().load_csv(r, compression="gzip")
@@ -471,21 +497,18 @@ class TestCachedQuery(BaseTest):
                 datetime.utcnow() + timedelta(days=1)]
 
         # Clear any previously cached file
-        q.clear_cache(sql_file="athena_test.sql",
-                      output_prefix="athena_test",
-                      params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
-
         r1 = q.get_results(sql_file="athena_test.sql",
-                          output_prefix="athena_test",
-                          params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
+                           output_prefix="athena_test",
+                           params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]},
+                           refresh_cache=True)
 
         r2 = q.get_results(sql_file="athena_test.sql",
-                          output_prefix="athena_test",
-                          params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
+                           output_prefix="athena_test",
+                           params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
 
         r3 = q.get_results(sql_file="athena_test.sql",
-                          output_prefix="athena_test",
-                          params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days[:2]]})
+                           output_prefix="athena_test",
+                           params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days[:2]]})
 
         q.wait_for_completion()
 
@@ -493,4 +516,4 @@ class TestCachedQuery(BaseTest):
         dfs = DoggoFileSystem()
         self.assertTrue(dfs.exists(r1))
         self.assertTrue(dfs.exists(r2))
-        self.assertTrue(dfs.exists(r3))
\ No newline at end of file
+        self.assertTrue(dfs.exists(r3))
