@@ -17,7 +17,7 @@ from s3fs import S3FileSystem
 
 from newtools import CSVDoggo, log_to_stdout
 from newtools import PandasDoggo, FileDoggo, S3Location, DoggoFileSystem, DoggoLock, DoggoWait, DynamoDogLock
-from newtools.optional_imports import boto3, AWSRetry
+from newtools.optional_imports import boto3
 from newtools.optional_imports import numpy as np
 from newtools.optional_imports import pandas as pd
 from .base_test import BaseTest
@@ -756,3 +756,77 @@ class TestPartitionDoggo(unittest.TestCase):
                                            name="/test_name_",
                                            suffix=".parquet",
                                            index=False)
+
+
+class TestDoggoFileSystem_2(unittest.TestCase):
+    @classmethod
+    def setUpClass(cls):
+        cls.base_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'test_data', 'doggofilesystem_tests')
+        cls.bucket = "newtools-testing"
+        cls.prefix = 'doggofilesystem_tests'
+        cls.path = S3Location(bucket=cls.bucket, key=cls.prefix)
+        cls.dfs = DoggoFileSystem()
+        cls.file_list = [
+            'doggofilesystem_tests/limit_test/test1.txt',
+            'doggofilesystem_tests/pixel/source_partition=pix.pub/date=2019-01-01/l_tag=dativa-health-check/2019-01-01_094118.631787.parquet',
+            'doggofilesystem_tests/pixel/source_partition=pix.pub/date=2019-01-01/l_tag=food-network-kitchen-app-across-channel/2019-01-01_094117.723581.parquet',
+            'doggofilesystem_tests/pixel/source_partition=pixels.dativa.com/date=2021-01-01/l_tag=dativa-health-check/2021-01-01_094118.631787.parquet',
+            'doggofilesystem_tests/pixel/source_partition=pixels.dativa.com/date=2021-01-01/l_tag=food-network-kitchen-app-across-channel/2021-01-01_094117.723581.parquet']
+
+    @classmethod
+    def tearDownClass(cls):
+        cls.dfs._delete_files(bucket=cls.bucket, prefix=cls.prefix)
+
+    def test_list(self):
+        self.dfs._put_folder(source=self.base_path, bucket=self.bucket, destination=self.prefix)
+        self.assertListEqual(self.file_list, self.dfs._list(self.path))
+        self.assertEqual(len(self.file_list), len(self.dfs._list(self.path)))
+        assert self.file_list[1] + f'{random()}' not in self.dfs._list(self.path)
+
+    def test_file_in_list_files(self):
+        self.dfs._put_folder(source=self.base_path, bucket=self.bucket, destination=self.prefix)
+        self.assertEqual(self.file_list, self.dfs._list_files(bucket=self.bucket, prefix=self.prefix))
+
+    def test_list_dict(self):
+        self.dfs._put_folder(source=self.base_path, bucket=self.bucket, destination=self.prefix)
+        self.files_on_s3 = [file['key'] for file in self.dfs._list_dict(path=self.path)]
+        self.assertEqual(self.file_list, self.files_on_s3)
+
+    def test_put_folder(self):
+        with self.assertRaises(ValueError):
+            self.dfs._put_folder(source=self.base_path + f'{random()}', bucket=self.bucket, destination=self.prefix)
+
+    def test_delete_one_file(self):
+        self.dfs._put_folder(source=self.base_path, bucket=self.bucket, destination=self.prefix)
+        self.dfs._delete_files(bucket=self.bucket, prefix=self.file_list[0])
+        self.assertEqual(self.file_list[1:], self.dfs._list_files(bucket=self.bucket, prefix=self.prefix))
+        with self.assertRaises(Exception):
+            self.dfs._delete_files(bucket=self.bucket + f'{random()}', prefix=self.file_list[1])
+
+    def test_delete_folders(self):
+        self.dfs._put_folder(source=self.base_path, bucket=self.bucket, destination=self.prefix)
+        self.dfs._delete(path=self.path)
+        self.assertEqual([], self.dfs._list_files(bucket=self.bucket, prefix=self.prefix))
+
+    def test_upper_limit(self):
+        for item in range(1002):
+            source = self.base_path + '/limit_test/'
+            prefix = self.prefix + f'/{item}/'
+            self.dfs._put_folder(source=source, bucket=self.bucket, destination=prefix)
+        self.assertEqual(self.dfs._list(path=self.path), self.dfs._list_files(bucket=self.bucket, prefix=self.prefix))
+        self.dfs._delete(path=self.path)
+        self.assertEqual([], self.dfs._list(path=self.path))
+
+    def test_ls(self):
+        all_files_in_bucket = self.dfs.ls(location=S3Location(bucket=self.bucket, key=None), recursive=True)
+        files_no_key_bucket = self.dfs.ls(location=S3Location(bucket=self.bucket), recursive=True)
+        self.assertEqual(all_files_in_bucket, files_no_key_bucket)
+
+        self.assertEqual(self.dfs.ls(location=f's3://{random()}/'), [])
+        self.assertEqual(self.dfs.ls(location=f's3://{self.bucket}/{random()}/'), [])
+
+        self.assertEqual(len(self.dfs.ls(self.base_path, recursive=True)), len(self.file_list))
+        self.assertEqual(self.dfs.ls(self.base_path + f'/{random()}/', recursive=True), [])
+
+        self.assertEqual(len(self.dfs.ls(self.base_path)), 2)
+        self.assertEqual(len(self.dfs.ls(self.base_path + f"{random()}")), 0)
