@@ -1,5 +1,5 @@
 import unittest
-from newtools.aws import AthenaPartition, S3List
+from newtools.aws import LoadPartitions, S3List
 from newtools.db import AthenaClient
 
 
@@ -16,7 +16,7 @@ class TestLoadPartitions(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         cls.s3_list_folders = S3List(cls.bucket)
-        cls.load_partitions = AthenaPartition(cls.bucket)
+        cls.load_partitions = LoadPartitions(cls.bucket)
         cls.athena_client = AthenaClient(region=cls.region, db=cls.database, max_retries=2)
 
         cls.athena_client.add_query(
@@ -78,6 +78,18 @@ class TestLoadPartitions(unittest.TestCase):
         self.assertCountEqual([x.strip() for x in sql_query_list[0].split('PARTITION')],
                               [x.strip() for x in test_sql_query_list[0].split('PARTITION')])
 
+    def test_get_sql_full_file_names(self):
+        sql_query_list = [
+            "ALTER TABLE load_partition_test_data ADD IF NOT EXISTS PARTITION(year='2019',month='02') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2019/month=02/some_more_directory' PARTITION(year='2019',month='0:2') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2019/month=0:2/some_more_directory' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory' PARTITION(year='2020',month='01') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory_1' PARTITION(year='2020',month='02') LOCATION 's3://newtools-tests-data/load_partition_test_data/year=2020/month=02/some_more_directory'"]
+        file_names = ['s3://newtools-tests-data/load_partition_test_data/year=2019/month=02/some_more_directory/file1.parquet.sz',
+                      's3://newtools-tests-data/load_partition_test_data/year=2019/month=0:2/some_more_directory/file2.parquet.sz',
+                      's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory/file3.parquet.sz',
+                      's3://newtools-tests-data/load_partition_test_data/year=2020/month=01/some_more_directory_1/file4.parquet.sz',
+                      's3://newtools-tests-data/load_partition_test_data/year=2020/month=02/some_more_directory/file5.parquet.sz']
+        test_sql_query_list = self.load_partitions.get_sql_from_file_names('load_partition_test_data', file_names)
+        self.assertCountEqual([x.strip() for x in sql_query_list[0].split('PARTITION')],
+                              [x.strip() for x in test_sql_query_list[0].split('PARTITION')])
+
     def test_generate_sql(self):
         partitions_list = {'load_partition_test_data/year=2019/month=02/some_more_directory/',
                            'load_partition_test_data/year=2019/month=0:2/some_more_directory/',
